@@ -30,4 +30,8 @@ class VcdFile(Proxy):
         avr_vcd_add_signal(self.backend, irq, bits, name);
         
     def terminate(self):
-        avr_vcd_close(self.backend)
\ No newline at end of file
+        avr_vcd_close(self.backend)
+
+    def __del__(self):
+        self.terminate()
+        
\ No newline at end of file
